# -*- coding: utf8 -*-

from django.conf import settings
from django.db import models

from portailuser.models import Ecole, PortailUser
from bbcode.models import BBCodeField
from datetime import timedelta, datetime


class PageWeb(models.Model):
    titre = models.CharField(max_length=32, verbose_name="Titre")
    adresse = models.CharField(
        max_length=64,
        verbose_name="Adresse de la page",
        help_text="Relative à la racine du site. Attention aux conflits avec les pages dynamiques…",
    )

    contenu = BBCodeField(pack="web_page_attach")

    ecole = models.ForeignKey(Ecole, editable=False, on_delete=models.CASCADE)

    class Meta:
        unique_together = (("ecole", "adresse"),)


def date_limite_edition():
    return datetime.now() + timedelta(minutes=settings.EDITION_TIME)


class JetonEditionPage(models.Model):
    page = models.OneToOneField(PageWeb, on_delete=models.CASCADE, primary_key=True)
    editeur = models.ForeignKey(PortailUser, on_delete=models.CASCADE)
    fin_jeton = models.DateTimeField(default=date_limite_edition)

    def renouvellement(self):
        self.fin_jeton = date_limite_edition()
        self.save()
